Generates a matrix containing all possible outcomes (all possible sequences of failure times and right-censoring times) of the value
of the Kaplan-Meier product-limit estimator for a particular sample
size n.
km.outcomes(n)The km.outcomes function returns a matrix with
2n+1-1 rows and n + 4 columns. The location l indicates the position where the time of interest falls within the observed events.
The meaning of the columns is as follows.
l: number of observed events (failures times or
censoring times) between times 0 and the observation time;
d1, d2, ..., dn: equals 0 if the event corresponds
to a censored observation, equals 1 if the event
corresponds to a failure;
S(t): numeric value of the associated support value;
num: numerator of the support value as a fraction;
den: denominator of the support value as a fraction.
sample size
Yuxin Qin (yqin08@wm.edu), Heather Sasinowska (hdsasinowska@wm.edu), Larry Leemis (leemis@math.wm.edu)
The Kaplan-Meier product-limit estimator is used to
estimate the survivor function for a data set of
positive values in the presence of right censoring.
The km.outcomes function generates a matrix with
all possible combinations of observed failures and
right censored values and the resulting support values
for the Kaplan-Meier product-limit estimator for a sample of
size n.
The n argument must be a positive integer denoting
the sample size. Allowable limits are from 1 to 24.
Larger values of n are not allowed because of CPU
and memory limitations.
In order to keep the support values as exact fractions,
the numerators and denominators are stored separately in
the a matrix in the columns named num and
den. The support values are stored as numeric
values in the column named S(t).
Qin, Y., Sasinowska, H., Leemis, L. (2023), "The Probability Mass Function of the Kaplan-Meier Product-Limit Estimator", \(The American Statistician\), Volume 77, Number 1, 102-110.